import ActionIcon from "@/components/ActionIcon/ActionIcon";
import { useNavigate } from "@solidjs/router";
import { IconX } from "@tabler/icons-solidjs";
import { prop } from "ramda";
import { children, mergeProps } from "solid-js";
import classes from "./ContentLayout.module.css";

/**
 * @typedef {Object} ContentLayoutProps
 * @property {boolean} [disableClose]
 * @property {JSX.Element} [title]
 */

/**
 * @param {import("solid-js").ParentProps<ContentLayoutProps>} props
 */
export default function ContentLayout(props) {
  const mergedProps = mergeProps({ disableClose: false, title: "" }, props);
  const childContent = children(() => props.children);
  const navigate = useNavigate();

  return (
    <div class={prop("content-layout", classes)}>
      <section class={prop("title", classes)}>
        <div class={prop("title-content", classes)}>{mergedProps.title}</div>
        <ActionIcon
          size="s"
          color="secondary"
          variant="transparent"
          disabled={mergedProps.disableClose}
          onClick={() => navigate("/", { replace: true })}
        >
          <IconX stroke="1.5" />
        </ActionIcon>
      </section>
      <section>{childContent()}</section>
    </div>
  );
}
